#
# spec file for package python-pytest-localserver
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with extras
%{?sle15_python_module_pythons}
Name:           python-pytest-localserver
Version:        0.8.1
Release:        1.8
Summary:        Plugin for py.test to test server connections locally
License:        MIT
URL:            https://github.com/pytest-dev/pytest-localserver
Source:         https://files.pythonhosted.org/packages/source/p/pytest-localserver/pytest-localserver-%{version}.tar.gz
BuildRequires:  %{python_module Werkzeug >= 0.10}
%if %{with extras}
BuildRequires:  %{python_module aiosmtpd}
%endif
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 2.0.0}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools >= 42}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module wheel}
%if 0%{?suse_version} <= 1500
# old setuptools_scm[toml] needs explicit extra
BuildRequires:  %{python_module toml}
%endif
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Werkzeug >= 0.10
Requires:       python-pytest >= 2.0.0
BuildArch:      noarch
%python_subpackages

%description
The pytest-localserver package is a plugin for the `pytest`_ testing framework
which enables you to test server connections locally.

Sometimes `monkeypatching`_ ``urllib2.urlopen()`` just does not cut it, for
instance if you work with ``urllib2.Request``, define your own openers/handlers
or work with ``httplib``. In these cases it may come in handy to have an HTTP
server running locally which behaves just like the real thing. Well, look
no further!

%prep
%setup -q -n pytest-localserver-%{version}
%autopatch -p1
sed -i "1d" pytest_localserver/{plugin,smtp}.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest %{?jobs: -n %jobs}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/pytest_localserver
%{python_sitelib}/pytest_localserver-%{version}*-info

%changelog
* Tue Nov  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.1:
  * Ignore AttributeError when shutting down server
  * Add support for Python 3.12 (or at least, list it explicitly
    in the classifiers)
* Mon Jul 24 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * Improve deployment workflow to use trusted publishing and
    upload to Test PyPI first
  * Remove a bunch of obsolete code
  * Clean up the smtp module's driver code
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.1:
  * Update SMTP server code to work with aiosmtpd >=1.4.3
  * Add support for Python 3.11 (or at least, list it explicitly
    in the classifiers)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Jan  9 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.0:
  * Make smtp support an optional extra
  * Update some obsolete syntax to drop support for Python 2
  * Add linting for code and workflow actions using pre-commit hooks
  * Expand the range of pytest versions known to be compatible, with tests
  * Add badges to README
* Mon Aug  1 2022 Ben Greiner <code@bnavigator.de>
- Update build requirements: Without setuptools_scm[toml], this
  installs a version 0.0.0 into the python metadata.
- Drop obsolete remove_bindir.patch
* Sun Jul 31 2022 Torsten Gruner <simmphonie@opensuse.org>
- Update to 0.6.0
  * Drop support for Python 3.3 and 3.4
  * Use setuptools_scm for managing versions of this package
  * Support sending chunked responses from the HTTP server
  * Switch SMTP server backend from smtpd to aiosmtpd
- version 0.5.1.post0
  * Explicitly list supported Python versions with python_requires in setup.py.
- version 0.5.1
  * Regenerate included certificate to use SHA-256 hash to avoid OpenSSL errors (fixes #2).
  * Add support for Python 3.10.
  * Drop support for Python 2.6.
  * Migrate repository to Github and update project metadata.
* Tue Mar 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use %%pytest call for testing
* Fri Feb 22 2019 Matej Cepl <mcepl@suse.com>
- Add remove_bindir.patch making test suite pass by removing
  '/usr/bin' from sys.path.
* Wed Feb 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop the patch python-pytest-localserver-do-not-use-shipped-pem.patch
  * We actually want the local pem as it is used just for the test
    spawning where we validate against it
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.0:
  * New feature: SMTP email message objects now include a ``details``
    property capturing the envelope details.
* Thu Feb 22 2018 mimi.vx@gmail.com
- update to 0.4.1
- fix requires
- remove tests - not work without internal certificate and buggy on
  python3
  * New feature: All received requests are now stored for ilater inspection
* Thu Aug 17 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 0.3.7
  * Add support for Python 3.6
* Sun Sep 18 2016 mardnh@gmx.de
- Fix URL
- Fix Source-URL
- Update to version 0.3.6
  + Add trove classifiers to make sure that package shows up on PyPI's Python 3 list.
  + Remove test method which rely on thread to be finished first.
  + OpenSSL is no longer necessary with werkzeug 0.10.
  + Tests now work under Python 3.3 \o/
  + Fix for Python 3.5 (fixes #13).
  + Add new Python version to classifiers.
  + Update repository url
  + Use @pytest.fixture to declare fixtures
  + Remove old-style test fixtures from tests and README, too.
* Mon Feb  9 2015 p.drouand@gmail.com
- Do not provide bundled certificate;
  add python-pytest-localserver-do-not-use-shipped-pem.patch
* Tue Nov  4 2014 hpj@urpla.net
- version 0.3.3: initial build
